# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDataFusionRestartInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionDeleteInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionCreateInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    instance: "dict[str, Any]"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionUpdateInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    instance: "dict[str, Any]"
    update_mask: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionGetInstanceOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionCreatePipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    pipeline: "dict[str, Any]"
    instance_name: "str"
    location: "str"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionDeletePipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    instance_name: "str"
    location: "str"
    version_id: "str | None"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionListPipelinesOperator(GoogleCloudBaseOperator):
    instance_name: "str"
    location: "str"
    artifact_name: "str | None"
    artifact_version: "str | None"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataFusionStartPipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    instance_name: "str"
    location: "str"
    pipeline_type: "DataFusionPipelineType"
    runtime_args: "dict[str, Any] | None"
    success_states: "list[str] | None"
    namespace: "str"
    pipeline_timeout: "int"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    asynchronous: "_empty"
    deferrable: "bool"
    poll_interval: "_empty"


class CloudDataFusionStopPipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    instance_name: "str"
    location: "str"
    namespace: "str"
    project_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpsgenieCreateAlertOperator(BaseOperator):
    message: "str"
    opsgenie_conn_id: "str"
    alias: "str | None"
    description: "str | None"
    responders: "list[dict] | None"
    visible_to: "list[dict] | None"
    actions: "list[str] | None"
    tags: "list[str] | None"
    details: "dict | None"
    entity: "str | None"
    source: "str | None"
    priority: "str | None"
    user: "str | None"
    note: "str | None"


class OpsgenieCloseAlertOperator(BaseOperator):
    identifier: "str"
    opsgenie_conn_id: "str"
    identifier_type: "str | None"
    user: "str | None"
    note: "str | None"
    source: "str | None"
    close_alert_kwargs: "dict | None"


class OpsgenieDeleteAlertOperator(BaseOperator):
    identifier: "str"
    opsgenie_conn_id: "str"
    identifier_type: "str | None"
    user: "str | None"
    source: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SalesforceBulkOperator(BaseOperator):
    operation: "Literal['insert', 'update', 'upsert', 'delete', 'hard_delete']"
    object_name: "str"
    payload: "list"
    external_id_field: "str"
    batch_size: "int"
    use_serial: "bool"
    salesforce_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class OSSKeySensor(BaseSensorOperator):
    bucket_key: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GrpcOperator(BaseOperator):
    stub_class: "Callable"
    call_func: "str"
    grpc_conn_id: "str"
    data: "dict | None"
    interceptors: "list[Callable] | None"
    custom_connection_func: "Callable | None"
    streaming: "bool"
    response_callback: "Callable | None"
    log_response: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToAzureBlobStorageOperator(BaseOperator):
    aws_conn_id: "str"
    wasb_conn_id: "str"
    s3_bucket: "str"
    container_name: "str"
    s3_prefix: "str | None"
    s3_key: "str | None"
    blob_prefix: "str | None"
    blob_name: "str | None"
    create_container: "bool"
    replace: "bool"
    s3_verify: "bool"
    s3_extra_args: "dict | None"
    wasb_extra_args: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBatchOperator(BaseOperator):
    batch_pool_id: "str"
    batch_pool_vm_size: "str"
    batch_job_id: "str"
    batch_task_command_line: "str"
    batch_task_id: "str"
    vm_node_agent_sku_id: "str"
    vm_publisher: "str | None"
    vm_offer: "str | None"
    sku_starts_with: "str | None"
    vm_sku: "str | None"
    vm_version: "str | None"
    os_family: "str | None"
    os_version: "str | None"
    batch_pool_display_name: "str | None"
    batch_job_display_name: "str | None"
    batch_job_manager_task: "batch_models.JobManagerTask | None"
    batch_job_preparation_task: "batch_models.JobPreparationTask | None"
    batch_job_release_task: "batch_models.JobReleaseTask | None"
    batch_task_display_name: "str | None"
    batch_task_container_settings: "batch_models.TaskContainerSettings | None"
    batch_start_task: "batch_models.StartTask | None"
    batch_max_retries: "int"
    batch_task_resource_files: "list[batch_models.ResourceFile] | None"
    batch_task_output_files: "list[batch_models.OutputFile] | None"
    batch_task_user_identity: "batch_models.UserIdentity | None"
    target_low_priority_nodes: "int | None"
    target_dedicated_nodes: "int | None"
    enable_auto_scale: "bool"
    auto_scale_formula: "str | None"
    azure_batch_conn_id: "_empty"
    use_latest_verified_vm_image_and_sku: "bool"
    timeout: "int"
    should_delete_job: "bool"
    should_delete_pool: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class EC2InstanceStateSensor(BaseSensorOperator):
    target_state: "str"
    instance_id: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToSqlOperator(BaseOperator):
    s3_key: "str"
    s3_bucket: "str"
    table: "str"
    parser: "Callable[[str], Iterable[Iterable]]"
    column_list: "list[str] | None"
    commit_every: "int"
    schema: "str | None"
    sql_conn_id: "str"
    sql_hook_params: "dict | None"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HttpToS3Operator(BaseOperator):
    endpoint: "str | None"
    method: "str"
    data: "Any"
    headers: "dict[str, str] | None"
    extra_options: "dict[str, Any] | None"
    http_conn_id: "str"
    log_response: "bool"
    auth_type: "type[AuthBase] | None"
    tcp_keep_alive: "bool"
    tcp_keep_alive_idle: "int"
    tcp_keep_alive_count: "int"
    tcp_keep_alive_interval: "int"
    s3_bucket: "str | None"
    s3_key: "str"
    replace: "bool"
    encrypt: "bool"
    acl_policy: "str | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class KinesisAnalyticsV2CreateApplicationOperator(AwsBaseOperator):
    application_name: "str"
    runtime_environment: "str"
    service_execution_role: "str"
    create_application_kwargs: "dict[str, Any] | None"
    application_description: "str"


class KinesisAnalyticsV2StartApplicationOperator(AwsBaseOperator):
    application_name: "str"
    run_configuration: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class KinesisAnalyticsV2StopApplicationOperator(AwsBaseOperator):
    application_name: "str"
    force: "bool"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudTranslateSpeechOperator(GoogleCloudBaseOperator):
    audio: "RecognitionAudio"
    config: "RecognitionConfig"
    target_language: "str"
    format_: "str"
    source_language: "str | None"
    model: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CassandraToGCSOperator(BaseOperator):
    cql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "str | None"
    approx_max_file_size_bytes: "int"
    gzip: "bool"
    cassandra_conn_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    query_timeout: "float | None | NotSetType"
    encode_uuid: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class KinesisAnalyticsV2BaseSensor(AwsBaseSensor):
    application_name: "str"
    deferrable: "bool"


class KinesisAnalyticsV2StartApplicationCompletedSensor(KinesisAnalyticsV2BaseSensor):
    application_name: "str"
    max_retries: "int"
    poke_interval: "int"


class KinesisAnalyticsV2StopApplicationCompletedSensor(KinesisAnalyticsV2BaseSensor):
    application_name: "str"
    max_retries: "int"
    poke_interval: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class LambdaFunctionStateSensor(AwsBaseSensor):
    function_name: "str"
    qualifier: "str | None"
    target_states: "list | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudComposerCreateEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    environment: "Environment | dict"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    deferrable: "bool"
    pooling_period_seconds: "int"


class CloudComposerDeleteEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    pooling_period_seconds: "int"


class CloudComposerGetEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudComposerListEnvironmentsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    page_size: "int | None"
    page_token: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudComposerUpdateEnvironmentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    environment: "dict | Environment"
    update_mask: "dict | FieldMask"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    pooling_period_seconds: "int"


class CloudComposerListImageVersionsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    page_size: "int | None"
    page_token: "str | None"
    include_past_releases: "bool"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudComposerRunAirflowCLICommandOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    command: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class DmsCreateTaskOperator(AwsBaseOperator):
    replication_task_id: "str"
    source_endpoint_arn: "str"
    target_endpoint_arn: "str"
    replication_instance_arn: "str"
    table_mappings: "dict"
    migration_type: "str"
    create_task_kwargs: "dict | None"
    aws_conn_id: "str | None"


class DmsDeleteTaskOperator(AwsBaseOperator):
    replication_task_arn: "str | None"


class DmsDescribeTasksOperator(AwsBaseOperator):
    describe_tasks_kwargs: "dict | None"


class DmsStartTaskOperator(AwsBaseOperator):
    replication_task_arn: "str"
    start_replication_task_type: "str"
    start_task_kwargs: "dict | None"
    aws_conn_id: "str | None"


class DmsStopTaskOperator(AwsBaseOperator):
    replication_task_arn: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudTextToSpeechSynthesizeOperator(GoogleCloudBaseOperator):
    input_data: "dict | SynthesisInput"
    voice: "dict | VoiceSelectionParams"
    audio_config: "dict | AudioConfig"
    target_bucket_name: "str"
    target_filename: "str"
    project_id: "str"
    gcp_conn_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DbtCloudJobRunSensor(BaseSensorOperator):
    dbt_cloud_conn_id: "str"
    run_id: "int"
    account_id: "int | None"
    deferrable: "bool"


class DbtCloudJobRunAsyncSensor(DbtCloudJobRunSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
    job_name: "str"
    expected_statuses: "set[str] | str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BatchOperator(BaseOperator):
    job_name: "str"
    job_definition: "str"
    job_queue: "str"
    overrides: "dict | None"
    container_overrides: "dict | None"
    array_properties: "dict | None"
    ecs_properties_override: "dict | None"
    node_overrides: "dict | None"
    share_identifier: "str | None"
    scheduling_priority_override: "int | None"
    parameters: "dict | None"
    retry_strategy: "dict | None"
    job_id: "str | None"
    waiters: "Any | None"
    max_retries: "int"
    status_retries: "int | None"
    aws_conn_id: "str | None"
    region_name: "str | None"
    tags: "dict | None"
    wait_for_completion: "bool"
    deferrable: "bool"
    poll_interval: "int"
    awslogs_enabled: "bool"
    awslogs_fetch_interval: "timedelta"


class BatchCreateComputeEnvironmentOperator(BaseOperator):
    compute_environment_name: "str"
    environment_type: "str"
    state: "str"
    compute_resources: "dict"
    unmanaged_v_cpus: "int | None"
    service_role: "str | None"
    tags: "dict | None"
    poll_interval: "int"
    max_retries: "int | None"
    aws_conn_id: "str | None"
    region_name: "str | None"
    deferrable: "bool"
    status_retries: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudBatchSubmitJobOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    job_name: "str"
    job: "dict | Job"
    polling_period_seconds: "float"
    timeout_seconds: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class CloudBatchDeleteJobOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    job_name: "str"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudBatchListJobsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    gcp_conn_id: "str"
    filter: "str | None"
    limit: "int | None"
    impersonation_chain: "str | Sequence[str] | None"


class CloudBatchListTasksOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    job_name: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    group_name: "str"
    filter: "str | None"
    limit: "int | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class TableauOperator(BaseOperator):
    resource: "str"
    method: "str"
    find: "str"
    match_with: "str"
    site_id: "str | None"
    blocking_refresh: "bool"
    check_interval: "float"
    tableau_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class BedrockInvokeModelOperator(AwsBaseOperator):
    model_id: "str"
    input_data: "dict[str, Any]"
    content_type: "str | None"
    accept_type: "str | None"


class BedrockCustomizeModelOperator(AwsBaseOperator):
    job_name: "str"
    custom_model_name: "str"
    role_arn: "str"
    base_model_id: "str"
    training_data_uri: "str"
    output_data_uri: "str"
    hyperparameters: "dict[str, str]"
    ensure_unique_job_name: "bool"
    customization_job_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class BedrockCreateProvisionedModelThroughputOperator(AwsBaseOperator):
    model_units: "int"
    provisioned_model_name: "str"
    model_id: "str"
    create_throughput_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class BedrockCreateKnowledgeBaseOperator(AwsBaseOperator):
    name: "str"
    embedding_model_arn: "str"
    role_arn: "str"
    storage_config: "dict[str, Any]"
    create_knowledge_base_kwargs: "dict[str, Any] | None"
    wait_for_indexing: "bool"
    indexing_error_retry_delay: "int"
    indexing_error_max_attempts: "int"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class BedrockCreateDataSourceOperator(AwsBaseOperator):
    name: "str"
    knowledge_base_id: "str"
    bucket_name: "str | None"
    create_data_source_kwargs: "dict[str, Any] | None"


class BedrockIngestDataOperator(AwsBaseOperator):
    knowledge_base_id: "str"
    data_source_id: "str"
    ingest_data_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class BedrockRaGOperator(AwsBaseOperator):
    input: "str"
    source_type: "str"
    model_arn: "str"
    prompt_template: "str | None"
    knowledge_base_id: "str | None"
    vector_search_config: "dict[str, Any] | None"
    sources: "list[dict[str, Any]] | None"
    rag_kwargs: "dict[str, Any] | None"


class BedrockRetrieveOperator(AwsBaseOperator):
    retrieval_query: "str"
    knowledge_base_id: "str"
    vector_search_config: "dict[str, Any] | None"
    retrieve_kwargs: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class SqsSensor(AwsBaseSensor):
    sqs_queue: "_empty"
    max_messages: "int"
    num_batches: "int"
    wait_time_seconds: "int"
    visibility_timeout: "int | None"
    message_filtering: "MessageFilteringType | None"
    message_filtering_match_values: "Any"
    message_filtering_config: "Any"
    delete_message_on_reception: "bool"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.bigtable import (
    BigtableValidationMixin,
)
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BigtableTableReplicationCompletedSensor(
    BaseSensorOperator, BigtableValidationMixin
):
    instance_id: "str"
    table_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudSQLBaseOperator(GoogleCloudBaseOperator):
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLCreateInstanceOperator(CloudSQLBaseOperator):
    body: "dict"
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLInstancePatchOperator(CloudSQLBaseOperator):
    body: "dict"
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLDeleteInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLCloneInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    destination_instance_name: "str"
    clone_context: "dict | None"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLCreateInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLPatchInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    database: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLDeleteInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    database: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLExportInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poke_interval: "int"


class CloudSQLImportInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudSQLExecuteQueryOperator(GoogleCloudBaseOperator):
    sql: "str | Iterable[str]"
    autocommit: "bool"
    parameters: "Iterable | Mapping[str, Any] | None"
    gcp_conn_id: "str"
    gcp_cloudsql_conn_id: "str"
    sql_proxy_binary_path: "str | None"
    ssl_server_cert: "str | None"
    ssl_client_cert: "str | None"
    ssl_client_key: "str | None"
    ssl_secret_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class PubSubPullSensor(BaseSensorOperator):
    project_id: "str"
    subscription: "str"
    max_messages: "int"
    ack_messages: "bool"
    gcp_conn_id: "str"
    messages_callback: "Callable[[list[ReceivedMessage], Context], Any] | None"
    impersonation_chain: "str | Sequence[str] | None"
    poke_interval: "float"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmailOperator(BaseOperator):
    to: "list[str] | str"
    subject: "str"
    html_content: "str"
    from_email: "str | None"
    files: "list | None"
    cc: "list[str] | str | None"
    bcc: "list[str] | str | None"
    mime_subtype: "str"
    mime_charset: "str"
    conn_id: "str"
    custom_headers: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class QuickSightSensor(AwsBaseSensor):
    data_set_id: "str"
    ingestion_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveStatsCollectionOperator(BaseOperator):
    table: "str"
    partition: "Any"
    extra_exprs: "dict[str, Any] | None"
    excluded_columns: "list[str] | None"
    assignment_func: "Callable[[str, str], dict[Any, Any] | None] | None"
    metastore_conn_id: "str"
    presto_conn_id: "str"
    mysql_conn_id: "str"
    ds: "str"
    dttm: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CreateEndpointOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint: "Endpoint | dict"
    endpoint_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteEndpointOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeployModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    deployed_model: "DeployedModel | dict"
    traffic_split: "Sequence | dict | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GetEndpointOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListEndpointsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    filter: "str | None"
    page_size: "int | None"
    page_token: "str | None"
    read_mask: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UndeployModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    endpoint_id: "str"
    deployed_model_id: "str"
    traffic_split: "Sequence | dict | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UpdateEndpointOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    endpoint_id: "str"
    endpoint: "Endpoint | dict"
    update_mask: "FieldMask | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class BigtableValidationMixin:
    pass


class BigtableCreateInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
    instance_id: "str"
    main_cluster_id: "str"
    main_cluster_zone: "str"
    project_id: "str"
    replica_clusters: "list[dict[str, str]] | None"
    instance_display_name: "str | None"
    instance_type: "enums.Instance.Type | None"
    instance_labels: "dict | None"
    cluster_nodes: "int | None"
    cluster_storage_type: "enums.StorageType | None"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigtableUpdateInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
    instance_id: "str"
    project_id: "str"
    instance_display_name: "str | None"
    instance_type: "enums.Instance.Type | enum.IntEnum | None"
    instance_labels: "dict | None"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigtableDeleteInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
    instance_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigtableCreateTableOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
    instance_id: "str"
    table_id: "str"
    project_id: "str"
    initial_split_keys: "list | None"
    column_families: "dict[str, GarbageCollectionRule] | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigtableDeleteTableOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
    instance_id: "str"
    table_id: "str"
    project_id: "str"
    app_profile_id: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigtableUpdateClusterOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
    instance_id: "str"
    cluster_id: "str"
    nodes: "int"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class EksBaseSensor(BaseSensorOperator):
    cluster_name: "str"
    target_state: "ClusterStates | NodegroupStates | FargateProfileStates"
    target_state_type: "type"
    aws_conn_id: "str | None"
    region: "str | None"


class EksClusterStateSensor(EksBaseSensor):
    target_state: "ClusterStates"


class EksFargateProfileStateSensor(EksBaseSensor):
    fargate_profile_name: "str"
    target_state: "FargateProfileStates"


class EksNodegroupStateSensor(EksBaseSensor):
    nodegroup_name: "str"
    target_state: "NodegroupStates"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SubDagOperator(BaseSensorOperator):
    subdag: "DAG"
    session: "Session"
    conf: "dict | None"
    propagate_skipped_state: "SkippedStatePropagationOptions | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SFTPSensor(BaseSensorOperator):
    path: "str"
    file_pattern: "str"
    newer_than: "datetime | str | None"
    sftp_conn_id: "str"
    python_callable: "Callable | None"
    op_args: "list | None"
    op_kwargs: "dict[str, Any] | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class GlacierJobOperationSensor(AwsBaseSensor):
    vault_name: "str"
    job_id: "str"
    poke_interval: "int"
    mode: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class PythonSensor(BaseSensorOperator):
    python_callable: "Callable"
    op_args: "list | None"
    op_kwargs: "Mapping[str, Any] | None"
    templates_dict: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class MySqlToHiveOperator(BaseOperator):
    sql: "str"
    hive_table: "str"
    create: "bool"
    recreate: "bool"
    partition: "dict | None"
    delimiter: "str"
    quoting: "int | None"
    quotechar: "str"
    escapechar: "str | None"
    mysql_conn_id: "str"
    hive_cli_conn_id: "str"
    hive_auth: "str | None"
    tblproperties: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CloudComposerEnvironmentSensor(BaseSensorOperator):
    pass


class CloudComposerDAGRunSensor(BaseSensorOperator):
    project_id: "str"
    region: "str"
    environment_id: "str"
    composer_dag_id: "str"
    allowed_states: "Iterable[str] | None"
    execution_range: "timedelta | list[datetime] | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.operators.bash import BashOperator


class _BashDecoratedOperator(DecoratedOperator, BashOperator):
    python_callable: "Callable"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DbtCloudRunJobOperator(BaseOperator):
    dbt_cloud_conn_id: "str"
    job_id: "int"
    account_id: "int | None"
    trigger_reason: "str | None"
    steps_override: "list[str] | None"
    schema_override: "str | None"
    wait_for_termination: "bool"
    timeout: "int"
    check_interval: "int"
    additional_run_config: "dict[str, Any] | None"
    reuse_existing_run: "bool"
    retry_from_failure: "bool"
    deferrable: "bool"


class DbtCloudGetJobRunArtifactOperator(BaseOperator):
    dbt_cloud_conn_id: "str"
    run_id: "int"
    path: "str"
    account_id: "int | None"
    step: "int | None"
    output_file_name: "str | None"


class DbtCloudListJobsOperator(BaseOperator):
    dbt_cloud_conn_id: "str"
    account_id: "int | None"
    project_id: "int | None"
    order_by: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBlobStorageToTeradataOperator(BaseOperator):
    blob_source_key: "str"
    public_bucket: "bool"
    azure_conn_id: "str"
    teradata_table: "str"
    teradata_conn_id: "str"
    teradata_authorization_name: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class GlueJobOperator(BaseOperator):
    job_name: "str"
    job_desc: "str"
    script_location: "str | None"
    concurrent_run_limit: "int | None"
    script_args: "dict | None"
    retry_limit: "int"
    num_of_dpus: "int | float | None"
    aws_conn_id: "str | None"
    region_name: "str | None"
    s3_bucket: "str | None"
    iam_role_name: "str | None"
    iam_role_arn: "str | None"
    create_job_kwargs: "dict | None"
    run_job_kwargs: "dict | None"
    wait_for_completion: "bool"
    deferrable: "bool"
    verbose: "bool"
    replace_script_file: "bool"
    update_config: "bool"
    job_poll_interval: "int | float"
    stop_job_run_on_kill: "bool"


class GlueDataQualityOperator(AwsBaseOperator):
    name: "str"
    ruleset: "str"
    description: "str"
    update_rule_set: "bool"
    data_quality_ruleset_kwargs: "dict | None"
    aws_conn_id: "str | None"


class GlueDataQualityRuleSetEvaluationRunOperator(AwsBaseOperator):
    datasource: "dict"
    role: "str"
    rule_set_names: "list[str]"
    number_of_workers: "int"
    timeout: "int"
    verify_result_status: "bool"
    show_results: "bool"
    rule_set_evaluation_run_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"


class GlueDataQualityRuleRecommendationRunOperator(AwsBaseOperator):
    datasource: "dict"
    role: "str"
    number_of_workers: "int"
    timeout: "int"
    show_results: "bool"
    recommendation_run_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class WorkflowExecutionSensor(BaseSensorOperator):
    workflow_id: "str"
    execution_id: "str"
    location: "str"
    project_id: "str"
    success_states: "set[Execution.State] | None"
    failure_states: "set[Execution.State] | None"
    retry: "Retry | _MethodDefault"
    request_timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class GoogleAnalyticsAdminListAccountsOperator(GoogleCloudBaseOperator):
    page_size: "int | None"
    page_token: "str | None"
    show_deleted: "bool | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleAnalyticsAdminCreatePropertyOperator(GoogleCloudBaseOperator):
    analytics_property: "Property | dict[str, Any]"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleAnalyticsAdminDeletePropertyOperator(GoogleCloudBaseOperator):
    property_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleAnalyticsAdminCreateDataStreamOperator(GoogleCloudBaseOperator):
    property_id: "str"
    data_stream: "DataStream | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleAnalyticsAdminDeleteDataStreamOperator(GoogleCloudBaseOperator):
    property_id: "str"
    data_stream_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleAnalyticsAdminListGoogleAdsLinksOperator(GoogleCloudBaseOperator):
    property_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleAnalyticsAdminGetGoogleAdsLinkOperator(GoogleCloudBaseOperator):
    property_id: "str"
    google_ads_link_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EC2StartInstanceOperator(BaseOperator):
    instance_id: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
    check_interval: "float"


class EC2StopInstanceOperator(BaseOperator):
    instance_id: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
    check_interval: "float"


class EC2CreateInstanceOperator(BaseOperator):
    image_id: "str"
    max_count: "int"
    min_count: "int"
    aws_conn_id: "str | None"
    region_name: "str | None"
    poll_interval: "int"
    max_attempts: "int"
    config: "dict | None"
    wait_for_completion: "bool"


class EC2TerminateInstanceOperator(BaseOperator):
    instance_ids: "str | list[str]"
    aws_conn_id: "str | None"
    region_name: "str | None"
    poll_interval: "int"
    max_attempts: "int"
    wait_for_completion: "bool"


class EC2RebootInstanceOperator(BaseOperator):
    instance_ids: "str | list[str]"
    aws_conn_id: "str | None"
    region_name: "str | None"
    poll_interval: "int"
    max_attempts: "int"
    wait_for_completion: "bool"


class EC2HibernateInstanceOperator(BaseOperator):
    instance_ids: "str | list[str]"
    aws_conn_id: "str | None"
    region_name: "str | None"
    poll_interval: "int"
    max_attempts: "int"
    wait_for_completion: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.taskmixin import DAGNode
from airfly._vendor.airflow.template.templater import Templater


class AbstractOperator(Templater, DAGNode):
    context: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class LivySensor(BaseSensorOperator):
    batch_id: "int | str"
    livy_conn_id: "str"
    livy_conn_auth_type: "Any | None"
    extra_options: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SingularityOperator(BaseOperator):
    image: "str"
    command: "str | ast.AST"
    start_command: "str | list[str] | None"
    environment: "dict[str, Any] | None"
    pull_folder: "str | None"
    working_dir: "str | None"
    force_pull: "bool | None"
    volumes: "list[str] | None"
    options: "list[str] | None"
    auto_remove: "bool | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.spark.operators.spark_submit import (
    SparkSubmitOperator,
)


class SparkJDBCOperator(SparkSubmitOperator):
    spark_app_name: "str"
    spark_conn_id: "str"
    spark_conf: "dict[str, Any] | None"
    spark_py_files: "str | None"
    spark_files: "str | None"
    spark_jars: "str | None"
    cmd_type: "str"
    jdbc_table: "str | None"
    jdbc_conn_id: "str"
    jdbc_driver: "str | None"
    metastore_table: "str | None"
    jdbc_truncate: "bool"
    save_mode: "str | None"
    save_format: "str | None"
    batch_size: "int | None"
    fetch_size: "int | None"
    num_partitions: "int | None"
    partition_column: "str | None"
    lower_bound: "str | None"
    upper_bound: "str | None"
    create_table_column_types: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DockerOperator(BaseOperator):
    image: "str"
    api_version: "str | None"
    command: "str | list[str] | None"
    container_name: "str | None"
    cpus: "float"
    docker_url: "str | list[str] | None"
    environment: "dict | None"
    private_environment: "dict | None"
    env_file: "str | None"
    force_pull: "bool"
    mem_limit: "float | str | None"
    host_tmp_dir: "str | None"
    network_mode: "str | None"
    tls_ca_cert: "str | None"
    tls_client_cert: "str | None"
    tls_client_key: "str | None"
    tls_verify: "bool"
    tls_hostname: "str | bool | None"
    tls_ssl_version: "str | None"
    mount_tmp_dir: "bool"
    tmp_dir: "str"
    user: "str | int | None"
    mounts: "list[Mount] | None"
    entrypoint: "str | list[str] | None"
    working_dir: "str | None"
    xcom_all: "bool"
    docker_conn_id: "str | None"
    dns: "list[str] | None"
    dns_search: "list[str] | None"
    auto_remove: "Literal['never', 'success', 'force']"
    shm_size: "int | None"
    tty: "bool"
    hostname: "str | None"
    privileged: "bool"
    cap_add: "Iterable[str] | None"
    extra_hosts: "dict[str, str] | None"
    retrieve_output: "bool"
    retrieve_output_path: "str | None"
    timeout: "int"
    device_requests: "list[DeviceRequest] | None"
    log_opts_max_size: "str | None"
    log_opts_max_file: "str | None"
    ipc_mode: "str | None"
    skip_on_exit_code: "int | Container[int] | None"
    port_bindings: "dict | None"
    ulimits: "list[Ulimit] | None"
    skip_exit_code: "int | Container[int] | ArgNotSet"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class EksCreateClusterOperator(BaseOperator):
    cluster_name: "str"
    cluster_role_arn: "str"
    resources_vpc_config: "dict"
    compute: "str | None"
    create_cluster_kwargs: "dict | None"
    nodegroup_name: "str"
    nodegroup_role_arn: "str | None"
    create_nodegroup_kwargs: "dict | None"
    fargate_profile_name: "str"
    fargate_pod_execution_role_arn: "str | None"
    fargate_selectors: "list | None"
    create_fargate_profile_kwargs: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    deferrable: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"


class EksCreateNodegroupOperator(BaseOperator):
    cluster_name: "str"
    nodegroup_subnets: "list[str] | str"
    nodegroup_role_arn: "str"
    nodegroup_name: "str"
    create_nodegroup_kwargs: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksCreateFargateProfileOperator(BaseOperator):
    cluster_name: "str"
    pod_execution_role_arn: "str"
    selectors: "list"
    fargate_profile_name: "str"
    create_fargate_profile_kwargs: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksDeleteClusterOperator(BaseOperator):
    cluster_name: "str"
    force_delete_compute: "bool"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    deferrable: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"


class EksDeleteNodegroupOperator(BaseOperator):
    cluster_name: "str"
    nodegroup_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksDeleteFargateProfileOperator(BaseOperator):
    cluster_name: "str"
    fargate_profile_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    region: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EksPodOperator(KubernetesPodOperator):
    cluster_name: "str"
    in_cluster: "bool"
    namespace: "str"
    pod_context: "str | None"
    pod_name: "str | None"
    pod_username: "str | None"
    aws_conn_id: "str | None"
    region: "str | None"
    on_finish_action: "str | None"
    is_delete_operator_pod: "bool | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ConsumeFromTopicOperator(BaseOperator):
    topics: "str | Sequence[str]"
    kafka_config_id: "str"
    apply_function: "Callable[..., Any] | str | None"
    apply_function_batch: "Callable[..., Any] | str | None"
    apply_function_args: "Sequence[Any] | None"
    apply_function_kwargs: "dict[Any, Any] | None"
    commit_cadence: "str | None"
    max_messages: "int | None"
    max_batch_size: "int"
    poll_timeout: "float"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SqlToS3Operator(BaseOperator):
    query: "str"
    s3_bucket: "str"
    s3_key: "str"
    sql_conn_id: "str"
    sql_hook_params: "dict | None"
    parameters: "None | Mapping[str, Any] | list | tuple"
    replace: "bool"
    aws_conn_id: "str | None"
    verify: "bool | str | None"
    file_format: "Literal['csv', 'json', 'parquet']"
    max_rows_per_file: "int"
    pd_kwargs: "dict | None"
    groupby_kwargs: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.branch import BaseBranchOperator


class BranchDateTimeOperator(BaseBranchOperator):
    follow_task_ids_if_true: "str | Iterable[str]"
    follow_task_ids_if_false: "str | Iterable[str]"
    target_lower: "datetime.datetime | datetime.time | None"
    target_upper: "datetime.datetime | datetime.time | None"
    use_task_logical_date: "bool"
    use_task_execution_date: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToTrinoOperator(BaseOperator):
    source_bucket: "str"
    source_object: "str"
    trino_table: "str"
    trino_conn_id: "str"
    gcp_conn_id: "str"
    schema_fields: "Iterable[str] | None"
    schema_object: "str | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3CreateBucketOperator(BaseOperator):
    bucket_name: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"


class S3DeleteBucketOperator(BaseOperator):
    bucket_name: "str"
    force_delete: "bool"
    aws_conn_id: "str | None"


class S3GetBucketTaggingOperator(BaseOperator):
    bucket_name: "str"
    aws_conn_id: "str | None"


class S3PutBucketTaggingOperator(BaseOperator):
    bucket_name: "str"
    key: "str | None"
    value: "str | None"
    tag_set: "dict | list[dict[str, str]] | None"
    aws_conn_id: "str | None"


class S3DeleteBucketTaggingOperator(BaseOperator):
    bucket_name: "str"
    aws_conn_id: "str | None"


class S3CopyObjectOperator(BaseOperator):
    source_bucket_key: "str"
    dest_bucket_key: "str"
    source_bucket_name: "str | None"
    dest_bucket_name: "str | None"
    source_version_id: "str | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"
    acl_policy: "str | None"


class S3CreateObjectOperator(BaseOperator):
    s3_bucket: "str | None"
    s3_key: "str"
    data: "str | bytes"
    replace: "bool"
    encrypt: "bool"
    acl_policy: "str | None"
    encoding: "str | None"
    compression: "str | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"


class S3DeleteObjectsOperator(BaseOperator):
    bucket: "str"
    keys: "str | list | None"
    prefix: "str | None"
    from_datetime: "datetime | None"
    to_datetime: "datetime | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"


class S3FileTransformOperator(BaseOperator):
    source_s3_key: "str"
    dest_s3_key: "str"
    transform_script: "str | None"
    select_expression: "_empty"
    select_expr_serialization_config: "dict[str, dict[str, dict]] | None"
    script_args: "Sequence[str] | None"
    source_aws_conn_id: "str | None"
    source_verify: "bool | str | None"
    dest_aws_conn_id: "str | None"
    dest_verify: "bool | str | None"
    replace: "bool"


class S3ListOperator(BaseOperator):
    bucket: "str"
    prefix: "str"
    delimiter: "str"
    aws_conn_id: "str | None"
    verify: "str | bool | None"
    apply_wildcard: "bool"


class S3ListPrefixesOperator(BaseOperator):
    bucket: "str"
    prefix: "str"
    delimiter: "str"
    aws_conn_id: "str | None"
    verify: "str | bool | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleSearchAdsInsertReportOperator(BaseOperator):
    report: "dict[str, Any]"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class GoogleSearchAdsDownloadReportOperator(BaseOperator):
    report_id: "str"
    bucket_name: "str"
    report_name: "str | None"
    gzip: "bool"
    chunk_size: "int"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSQLToGCSOperator(BaseOperator):
    sql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "str | None"
    approx_max_file_size_bytes: "int"
    export_format: "str"
    stringify_dict: "bool"
    field_delimiter: "str"
    null_marker: "str | None"
    gzip: "bool"
    schema: "str | list | None"
    parameters: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    upload_metadata: "bool"
    exclude_columns: "set | None"
    partition_columns: "list | None"
    write_on_empty: "bool"
    parquet_row_group_size: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.operators.python import PythonOperator


class _PySparkDecoratedOperator(DecoratedOperator, PythonOperator):
    python_callable: "Callable"
    op_args: "Sequence | None"
    op_kwargs: "dict | None"
    conn_id: "str | None"
    config_kwargs: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataprepJobGroupIsFinishedSensor(BaseSensorOperator):
    job_group_id: "int | str"
    dataprep_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class AutoMLTrainingJobBaseOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    display_name: "str"
    labels: "dict[str, str] | None"
    parent_model: "str | None"
    is_default_version: "bool | None"
    model_version_aliases: "list[str] | None"
    model_version_description: "str | None"
    training_encryption_spec_key_name: "str | None"
    model_encryption_spec_key_name: "str | None"
    training_fraction_split: "float | None"
    test_fraction_split: "float | None"
    model_display_name: "str | None"
    model_labels: "dict[str, str] | None"
    sync: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CreateAutoMLForecastingTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    target_column: "str"
    time_column: "str"
    time_series_identifier_column: "str"
    unavailable_at_forecast_columns: "list[str]"
    available_at_forecast_columns: "list[str]"
    forecast_horizon: "int"
    data_granularity_unit: "str"
    data_granularity_count: "int"
    optimization_objective: "str | None"
    column_specs: "dict[str, str] | None"
    column_transformations: "list[dict[str, dict[str, str]]] | None"
    validation_fraction_split: "float | None"
    predefined_split_column_name: "str | None"
    weight_column: "str | None"
    time_series_attribute_columns: "list[str] | None"
    context_window: "int | None"
    export_evaluated_data_items: "bool"
    export_evaluated_data_items_bigquery_destination_uri: "str | None"
    export_evaluated_data_items_override_destination: "bool"
    quantiles: "list[float] | None"
    validation_options: "str | None"
    budget_milli_node_hours: "int"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"
    window_stride_length: "int | None"
    window_max_count: "int | None"


class CreateAutoMLImageTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    prediction_type: "str"
    multi_label: "bool"
    model_type: "str"
    base_model: "Model | None"
    validation_fraction_split: "float | None"
    training_filter_split: "str | None"
    validation_filter_split: "str | None"
    test_filter_split: "str | None"
    budget_milli_node_hours: "int | None"
    disable_early_stopping: "bool"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"


class CreateAutoMLTabularTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    target_column: "str"
    optimization_prediction_type: "str"
    optimization_objective: "str | None"
    column_specs: "dict[str, str] | None"
    column_transformations: "list[dict[str, dict[str, str]]] | None"
    optimization_objective_recall_value: "float | None"
    optimization_objective_precision_value: "float | None"
    validation_fraction_split: "float | None"
    predefined_split_column_name: "str | None"
    timestamp_split_column_name: "str | None"
    weight_column: "str | None"
    budget_milli_node_hours: "int"
    disable_early_stopping: "bool"
    export_evaluated_data_items: "bool"
    export_evaluated_data_items_bigquery_destination_uri: "str | None"
    export_evaluated_data_items_override_destination: "bool"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"


class CreateAutoMLTextTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    prediction_type: "str"
    multi_label: "bool"
    sentiment_max: "int"
    validation_fraction_split: "float | None"
    training_filter_split: "str | None"
    validation_filter_split: "str | None"
    test_filter_split: "str | None"


class CreateAutoMLVideoTrainingJobOperator(AutoMLTrainingJobBaseOperator):
    dataset_id: "str"
    prediction_type: "str"
    model_type: "str"
    training_filter_split: "str | None"
    test_filter_split: "str | None"
    region: "str"
    impersonation_chain: "str | Sequence[str] | None"
    parent_model: "str | None"


class DeleteAutoMLTrainingJobOperator(GoogleCloudBaseOperator):
    training_pipeline_id: "str"
    region: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListAutoMLTrainingJobOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    read_mask: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class TimeSensor(BaseSensorOperator):
    target_time: "datetime.time"


class TimeSensorAsync(BaseSensorOperator):
    target_time: "datetime.time"
    start_from_trigger: "bool"
    trigger_kwargs: "dict[str, Any] | None"
    end_from_trigger: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.base import (
    AwsToAwsBaseOperator,
)


class DynamoDBToS3Operator(AwsToAwsBaseOperator):
    dynamodb_table_name: "str"
    s3_bucket_name: "str"
    file_size: "int"
    dynamodb_scan_kwargs: "dict[str, Any] | None"
    s3_key_prefix: "str"
    process_func: "Callable[[dict[str, Any]], bytes]"
    export_time: "datetime | None"
    export_format: "str"
    check_interval: "int"
    max_attempts: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DataplexCreateTaskOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    body: "dict[str, Any]"
    dataplex_task_id: "str"
    validate_only: "bool | None"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    asynchronous: "bool"


class DataplexDeleteTaskOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    dataplex_task_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexListTasksOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    order_by: "str | None"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexGetTaskOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    dataplex_task_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexCreateLakeOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    body: "dict[str, Any]"
    validate_only: "bool | None"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    asynchronous: "bool"


class DataplexDeleteLakeOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexCreateOrUpdateDataQualityScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    body: "dict[str, Any] | DataScan"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    update_mask: "dict | FieldMask | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexGetDataQualityScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexDeleteDataQualityScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexRunDataQualityScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    asynchronous: "bool"
    fail_on_dq_failure: "bool"
    result_timeout: "float"
    deferrable: "bool"
    polling_interval_seconds: "int"


class DataplexGetDataQualityScanResultOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    job_id: "str | None"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    fail_on_dq_failure: "bool"
    wait_for_results: "bool"
    result_timeout: "float"
    deferrable: "bool"
    polling_interval_seconds: "int"


class DataplexCreateOrUpdateDataProfileScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    body: "dict[str, Any] | DataScan"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    update_mask: "dict | FieldMask | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexGetDataProfileScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexDeleteDataProfileScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexRunDataProfileScanOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    asynchronous: "bool"
    result_timeout: "float"
    deferrable: "bool"
    polling_interval_seconds: "int"


class DataplexGetDataProfileScanResultOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    data_scan_id: "str"
    job_id: "str | None"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    wait_for_results: "bool"
    result_timeout: "float"


class DataplexCreateZoneOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    body: "dict[str, Any] | Zone"
    zone_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexDeleteZoneOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    zone_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexCreateAssetOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    body: "dict[str, Any] | Asset"
    zone_id: "str"
    asset_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataplexDeleteAssetOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    lake_id: "str"
    zone_id: "str"
    asset_id: "str"
    api_version: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class FileSensor(BaseSensorOperator):
    filepath: "_empty"
    fs_conn_id: "_empty"
    recursive: "_empty"
    deferrable: "bool"
    start_from_trigger: "bool"
    trigger_kwargs: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class WinRMOperator(BaseOperator):
    winrm_hook: "WinRMHook | None"
    ssh_conn_id: "str | None"
    remote_host: "str | None"
    command: "str | None"
    ps_path: "str | None"
    output_encoding: "str"
    timeout: "int"



import importlib
from functools import lru_cache
from typing import Dict, Type

from airfly._vendor import airflow
from airfly.utils import collect_objects, qualname


@lru_cache()
def collect_airflow_operators() -> Dict[str, Type]:

    vendor = importlib.import_module(qualname(airflow))
    collected = {}

    for item in collect_objects(vendor, lambda obj: isinstance(obj, type)):

        basename = qualname(item, level=1)
        if basename not in collected:
            collected[basename] = []

        if item not in collected[basename]:
            collected[basename].append(item)

    return collected



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToGCSOperator(BaseOperator):
    source_project_dataset_table: "str"
    destination_cloud_storage_uris: "list[str]"
    project_id: "str"
    compression: "str"
    export_format: "str"
    field_delimiter: "str"
    print_header: "bool"
    gcp_conn_id: "str"
    labels: "dict | None"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    result_retry: "Retry"
    result_timeout: "float | None"
    job_id: "str | None"
    force_rerun: "bool"
    reattach_states: "set[str] | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AzureDataFactoryPipelineRunStatusSensor(BaseSensorOperator):
    run_id: "str"
    azure_data_factory_conn_id: "str"
    resource_group_name: "str"
    factory_name: "str"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FTPToS3Operator(BaseOperator):
    ftp_path: "str"
    s3_bucket: "str"
    s3_key: "str"
    ftp_filenames: "str | list[str] | None"
    s3_filenames: "str | list[str] | None"
    ftp_conn_id: "str"
    aws_conn_id: "str | None"
    replace: "bool"
    encrypt: "bool"
    gzip: "bool"
    acl_policy: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SFTPToGCSOperator(BaseOperator):
    source_path: "str"
    destination_bucket: "str"
    destination_path: "str | None"
    gcp_conn_id: "str"
    sftp_conn_id: "str"
    mime_type: "str"
    gzip: "bool"
    move_object: "bool"
    impersonation_chain: "str | Sequence[str] | None"
    sftp_prefetch: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SageMakerBaseOperator(BaseOperator):
    config: "dict"
    aws_conn_id: "str | None"


class SageMakerProcessingOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"
    wait_for_completion: "bool"
    print_log: "bool"
    check_interval: "int"
    max_attempts: "int | None"
    max_ingestion_time: "int | None"
    action_if_job_exists: "str"
    deferrable: "bool"


class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"


class SageMakerEndpointOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"
    wait_for_completion: "bool"
    check_interval: "int"
    max_ingestion_time: "int | None"
    operation: "str"
    deferrable: "bool"


class SageMakerTransformOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"
    wait_for_completion: "bool"
    check_interval: "int"
    max_attempts: "int | None"
    max_ingestion_time: "int | None"
    check_if_job_exists: "bool"
    action_if_job_exists: "str"
    check_if_model_exists: "bool"
    action_if_model_exists: "str"
    deferrable: "bool"


class SageMakerTuningOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"
    wait_for_completion: "bool"
    check_interval: "int"
    max_ingestion_time: "int | None"
    deferrable: "bool"


class SageMakerModelOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"


class SageMakerTrainingOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"
    wait_for_completion: "bool"
    print_log: "bool"
    check_interval: "int"
    max_attempts: "int | None"
    max_ingestion_time: "int | None"
    check_if_job_exists: "bool"
    action_if_job_exists: "str"
    deferrable: "bool"


class SageMakerDeleteModelOperator(SageMakerBaseOperator):
    config: "dict"
    aws_conn_id: "str | None"


class SageMakerStartPipelineOperator(SageMakerBaseOperator):
    aws_conn_id: "str | None"
    pipeline_name: "str"
    display_name: "str"
    pipeline_params: "dict | None"
    wait_for_completion: "bool"
    check_interval: "int"
    waiter_max_attempts: "int"
    verbose: "bool"
    deferrable: "bool"


class SageMakerStopPipelineOperator(SageMakerBaseOperator):
    aws_conn_id: "str | None"
    pipeline_exec_arn: "str"
    wait_for_completion: "bool"
    check_interval: "int"
    waiter_max_attempts: "int"
    verbose: "bool"
    fail_if_not_running: "bool"
    deferrable: "bool"


class SageMakerRegisterModelVersionOperator(SageMakerBaseOperator):
    image_uri: "str"
    model_url: "str"
    package_group_name: "str"
    package_group_desc: "str"
    package_desc: "str"
    model_approval: "ApprovalStatus"
    extras: "dict | None"
    aws_conn_id: "str | None"
    config: "dict | None"


class SageMakerAutoMLOperator(SageMakerBaseOperator):
    job_name: "str"
    s3_input: "str"
    target_attribute: "str"
    s3_output: "str"
    role_arn: "str"
    compressed_input: "bool"
    time_limit: "int | None"
    autodeploy_endpoint_name: "str | None"
    extras: "dict | None"
    wait_for_completion: "bool"
    check_interval: "int"
    aws_conn_id: "str | None"
    config: "dict | None"


class SageMakerCreateExperimentOperator(SageMakerBaseOperator):
    name: "str"
    description: "str | None"
    tags: "dict | None"
    aws_conn_id: "str | None"


class SageMakerCreateNotebookOperator(BaseOperator):
    instance_name: "str"
    instance_type: "str"
    role_arn: "str"
    volume_size_in_gb: "int | None"
    volume_kms_key_id: "str | None"
    lifecycle_config_name: "str | None"
    direct_internet_access: "str | None"
    root_access: "str | None"
    create_instance_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"


class SageMakerStopNotebookOperator(BaseOperator):
    instance_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"


class SageMakerDeleteNotebookOperator(BaseOperator):
    instance_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"


class SageMakerStartNoteBookOperator(BaseOperator):
    instance_name: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"



import pytest


@pytest.mark.parametrize(
    "src,exp",
    [
        (["", "", ""], ["\n"]),
        (
            ["def foo():", "    ", "    ", "    ", "    pass"],
            ["def foo():", "", "    pass", ""],
        ),
        (
            ["import os", "def foo():", "    pass"],
            ["import os", "", "", "def foo():", "    pass", ""],
        ),
    ],
)
def test_blacking(src, exp):
    from airfly.utils import blacking

    assert blacking("\n".join(src)) == "\n".join(exp)


@pytest.mark.parametrize(
    "src,exp",
    [
        (["import sys", "import os"], ["import os", "import sys", ""]),
        (["import airfly", "import os"], ["import os", "", "import airfly", ""]),
        (
            ["from airfly.utils import qualname", "import airfly"],
            ["import airfly", "from airfly.utils import qualname", ""],
        ),
        (
            ["from . import isorting", "import airfly"],
            ["import airfly", "", "from . import isorting", ""],
        ),
    ],
)
def test_isorting(src, exp):
    from airfly.utils import isorting

    assert isorting("\n".join(src)) == "\n".join(exp)


def test_collect_objects(mocker):

    mock_collect_from_package = mocker.patch("airfly.utils._collect_from_package")
    mock_collect_from_module = mocker.patch("airfly.utils._collect_from_module")
    import airfly
    from airfly import utils
    from airfly.utils import collect_objects

    _ = list(collect_objects(airfly))

    assert (
        mock_collect_from_package.call_count == 1
        and mock_collect_from_module.call_count == 0
    )

    mocker.resetall()

    _ = list(collect_objects(utils))
    assert (
        mock_collect_from_package.call_count == 0
        and mock_collect_from_module.call_count == 1
    )


def test_qualname():
    from airfly.utils import qualname

    assert qualname(qualname) == "airfly.utils.qualname"
    assert qualname(qualname, level=2) == "utils.qualname"
    assert qualname(qualname, level=100) == "airfly.utils.qualname"
    assert qualname(qualname, level=-1) == "airfly.utils.qualname"


def test__escape_any_commandline_parser():
    from airfly.utils import _escape_any_commandline_parser

    assert _escape_any_commandline_parser


def test__collect_from_package():
    from airfly.utils import _collect_from_package

    assert _collect_from_package


def test__collect_from_module():
    from airfly.utils import _collect_from_module

    assert _collect_from_module


def test_makefile():
    from airfly.utils import makefile

    assert makefile


def test__writefile():
    from airfly.utils import _writefile

    assert _writefile


def test_issubclass_by_qualname():
    from airfly.utils import issubclass_by_qualname

    class Foo: ...

    class Bar(Foo): ...

    class Buz: ...

    assert issubclass_by_qualname(Bar, Foo)
    assert not issubclass_by_qualname(Buz, Foo)



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SlackWebhookOperator(BaseOperator):
    slack_webhook_conn_id: "_empty"
    message: "str"
    attachments: "list | None"
    blocks: "list | None"
    channel: "str | None"
    username: "str | None"
    icon_emoji: "str | None"
    icon_url: "str | None"
    proxy: "str | None"
    timeout: "int | None"
    retry_handlers: "list[RetryHandler] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.abc import ABC
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BeamDataflowMixin:
    pass


class BeamBasePipelineOperator(BaseOperator, BeamDataflowMixin, ABC):
    runner: "str"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"


class BeamRunPythonPipelineOperator(BeamBasePipelineOperator):
    py_file: "str"
    runner: "str"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    py_interpreter: "str"
    py_options: "list[str] | None"
    py_requirements: "list[str] | None"
    py_system_site_packages: "bool"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"
    deferrable: "bool"


class BeamRunJavaPipelineOperator(BeamBasePipelineOperator):
    jar: "str"
    runner: "str"
    job_class: "str | None"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"
    deferrable: "bool"


class BeamRunGoPipelineOperator(BeamBasePipelineOperator):
    go_file: "str"
    launcher_binary: "str"
    worker_binary: "str"
    runner: "str"
    default_pipeline_options: "dict | None"
    pipeline_options: "dict | None"
    gcp_conn_id: "str"
    dataflow_config: "DataflowConfiguration | dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HttpOperator(BaseOperator):
    endpoint: "str | None"
    method: "str"
    data: "dict[str, Any] | str | None"
    headers: "dict[str, str] | None"
    pagination_function: "Callable[..., Any] | None"
    response_check: "Callable[..., bool] | None"
    response_filter: "Callable[..., Any] | None"
    extra_options: "dict[str, Any] | None"
    http_conn_id: "str"
    log_response: "bool"
    auth_type: "type[AuthBase] | None"
    tcp_keep_alive: "bool"
    tcp_keep_alive_idle: "int"
    tcp_keep_alive_count: "int"
    tcp_keep_alive_interval: "int"
    deferrable: "bool"
    retry_args: "dict[str, Any] | None"


class SimpleHttpOperator(HttpOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class PostgresToGCSOperator(BaseSQLToGCSOperator):
    postgres_conn_id: "_empty"
    use_server_side_cursor: "_empty"
    cursor_itersize: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class DataSyncOperator(AwsBaseOperator):
    wait_interval_seconds: "int"
    max_iterations: "int"
    wait_for_completion: "bool"
    task_arn: "str | None"
    source_location_uri: "str | None"
    destination_location_uri: "str | None"
    allow_random_task_choice: "bool"
    allow_random_location_choice: "bool"
    create_task_kwargs: "dict | None"
    create_source_location_kwargs: "dict | None"
    create_destination_location_kwargs: "dict | None"
    update_task_kwargs: "dict | None"
    task_execution_kwargs: "dict | None"
    delete_task_after_execution: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class YQExecuteQueryOperator(BaseOperator):
    name: "str | None"
    folder_id: "str | None"
    yandex_conn_id: "str | None"
    public_ssh_key: "str | None"
    service_account_id: "str | None"
    sql: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveToDynamoDBOperator(BaseOperator):
    sql: "str"
    table_name: "str"
    table_keys: "list"
    pre_process: "Callable | None"
    pre_process_args: "list | None"
    pre_process_kwargs: "list | None"
    region_name: "str | None"
    schema: "str"
    hiveserver2_conn_id: "str"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class WasbBlobSensor(BaseSensorOperator):
    container_name: "str"
    blob_name: "str"
    wasb_conn_id: "str"
    check_options: "dict | None"
    public_read: "bool"
    deferrable: "bool"


class WasbBlobAsyncSensor(WasbBlobSensor):
    pass


class WasbPrefixSensor(BaseSensorOperator):
    container_name: "str"
    prefix: "str"
    wasb_conn_id: "str"
    check_options: "dict | None"
    public_read: "bool"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class MSGraphSensor(BaseSensorOperator):
    url: "str"
    response_type: "ResponseType | None"
    path_parameters: "dict[str, Any] | None"
    url_template: "str | None"
    method: "str"
    query_parameters: "dict[str, QueryParams] | None"
    headers: "dict[str, str] | None"
    data: "dict[str, Any] | str | BytesIO | None"
    conn_id: "str"
    proxies: "dict | None"
    api_version: "APIVersion | None"
    event_processor: "Callable[[Context, Any], bool]"
    result_processor: "Callable[[Context, Any], Any]"
    serializer: "type[ResponseSerializer]"
    retry_delay: "timedelta | float"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    display_name: "str"
    metric_spec: "dict[str, str]"
    parameter_spec: "dict[str, hyperparameter_tuning._ParameterSpec]"
    max_trial_count: "int"
    parallel_trial_count: "int"
    worker_pool_specs: "list[dict] | list[gapic.WorkerPoolSpec]"
    base_output_dir: "str | None"
    custom_job_labels: "dict[str, str] | None"
    custom_job_encryption_spec_key_name: "str | None"
    staging_bucket: "str | None"
    max_failed_trial_count: "int"
    search_algorithm: "str | None"
    measurement_selection: "str | None"
    hyperparameter_tuning_job_labels: "dict[str, str] | None"
    hyperparameter_tuning_job_encryption_spec_key_name: "str | None"
    service_account: "str | None"
    network: "str | None"
    timeout: "int | None"
    restart_job_on_worker_restart: "bool"
    enable_web_access: "bool"
    tensorboard: "str | None"
    sync: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    hyperparameter_tuning_job_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    hyperparameter_tuning_job_id: "str"
    region: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    read_mask: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CreateDatasetOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset: "Dataset | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GetDatasetOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    read_mask: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteDatasetOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ExportDataOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    export_config: "ExportDataConfig | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ImportDataOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    dataset_id: "str"
    import_configs: "Sequence[ImportDataConfig] | list"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListDatasetsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    filter: "str | None"
    page_size: "int | None"
    page_token: "str | None"
    read_mask: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UpdateDatasetOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    dataset_id: "str"
    dataset: "Dataset | dict"
    update_mask: "FieldMask | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class RedisPublishOperator(BaseOperator):
    channel: "str"
    message: "str"
    redis_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PineconeIngestOperator(BaseOperator):
    conn_id: "str"
    index_name: "str"
    input_vectors: "list[Vector] | list[tuple] | list[dict]"
    namespace: "str"
    batch_size: "int | None"
    upsert_kwargs: "dict | None"


class CreatePodIndexOperator(BaseOperator):
    conn_id: "str"
    index_name: "str"
    dimension: "int"
    environment: "str | None"
    replicas: "int | None"
    shards: "int | None"
    pods: "int | None"
    pod_type: "str"
    metadata_config: "dict | None"
    source_collection: "str | None"
    metric: "str"
    timeout: "int | None"


class CreateServerlessIndexOperator(BaseOperator):
    conn_id: "str"
    index_name: "str"
    dimension: "int"
    cloud: "str"
    region: "str | None"
    metric: "str | None"
    timeout: "int | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FileTransferOperator(BaseOperator):
    src: "str | ObjectStoragePath"
    dst: "str | ObjectStoragePath"
    source_conn_id: "str | None"
    dest_conn_id: "str | None"
    overwrite: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class QdrantIngestOperator(BaseOperator):
    conn_id: "str"
    collection_name: "str"
    vectors: "Iterable[VectorStruct]"
    payload: "Iterable[dict[str, Any]] | None"
    ids: "Iterable[int | str] | None"
    batch_size: "int"
    parallel: "int"
    method: "str | None"
    max_retries: "int"
    wait: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleDriveToLocalOperator(BaseOperator):
    output_file: "str"
    file_name: "str"
    folder_id: "str"
    drive_id: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# NOTE: This file is auto-generated by "inv sync-meta"


name = "airfly"
version = "1.1.0"
description = "Auto generate Airflow's dag.py on the fly"
authors = [{"name": "ryanchao2012", "email": "ryanchao2012@gmail.com"}]
readme = "README.md"
license = {"text": "MIT"}
classifiers = [
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: 3.11",
    "Programming Language :: Python :: 3.12",
]
requires_python = ">=3.8"
dependencies = [
    "attrs",
    "cattrs",
    "regex",
    "networkx",
    "black",
    "isort",
    "click",
    "libcst",
    "asttrs",
    "loguru",
]
optional_dependencies = {
    "dev": [
        "ipython>=8.12.3",
        "pytest>=8.1.1",
        "invoke>=2.2.0",
        "pytest-cov>=4.1.0",
        "gutt>=1.1.0",
        "toml>=0.10.2",
        "pytest-mock>=3.14.0",
    ]
}
scripts = {"airfly": "airfly.cli.main:main"}



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class PubSubCreateTopicOperator(GoogleCloudBaseOperator):
    topic: "str"
    project_id: "str"
    fail_if_exists: "bool"
    gcp_conn_id: "str"
    labels: "dict[str, str] | None"
    message_storage_policy: "dict | MessageStoragePolicy"
    kms_key_name: "str | None"
    schema_settings: "dict | SchemaSettings"
    message_retention_duration: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    impersonation_chain: "str | Sequence[str] | None"


class PubSubCreateSubscriptionOperator(GoogleCloudBaseOperator):
    topic: "str"
    project_id: "str"
    subscription: "str | None"
    subscription_project_id: "str | None"
    ack_deadline_secs: "int"
    fail_if_exists: "bool"
    gcp_conn_id: "str"
    push_config: "dict | PushConfig | None"
    retain_acked_messages: "bool | None"
    message_retention_duration: "dict | Duration | None"
    labels: "dict[str, str] | None"
    enable_message_ordering: "bool"
    expiration_policy: "dict | ExpirationPolicy | None"
    filter_: "str | None"
    dead_letter_policy: "dict | DeadLetterPolicy | None"
    retry_policy: "dict | RetryPolicy | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    impersonation_chain: "str | Sequence[str] | None"


class PubSubDeleteTopicOperator(GoogleCloudBaseOperator):
    topic: "str"
    project_id: "str"
    fail_if_not_exists: "bool"
    gcp_conn_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    impersonation_chain: "str | Sequence[str] | None"


class PubSubDeleteSubscriptionOperator(GoogleCloudBaseOperator):
    subscription: "str"
    project_id: "str"
    fail_if_not_exists: "bool"
    gcp_conn_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    impersonation_chain: "str | Sequence[str] | None"


class PubSubPublishMessageOperator(GoogleCloudBaseOperator):
    topic: "str"
    messages: "list"
    project_id: "str"
    gcp_conn_id: "str"
    enable_message_ordering: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class PubSubPullOperator(GoogleCloudBaseOperator):
    project_id: "str"
    subscription: "str"
    max_messages: "int"
    ack_messages: "bool"
    messages_callback: "Callable[[list[ReceivedMessage], Context], Any] | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class EventBridgePutEventsOperator(AwsBaseOperator):
    entries: "list[dict]"
    endpoint_id: "str | None"


class EventBridgePutRuleOperator(AwsBaseOperator):
    name: "str"
    description: "str | None"
    event_bus_name: "str | None"
    event_pattern: "str | None"
    role_arn: "str | None"
    schedule_expression: "str | None"
    state: "str | None"
    tags: "list | None"


class EventBridgeEnableRuleOperator(AwsBaseOperator):
    name: "str"
    event_bus_name: "str | None"


class EventBridgeDisableRuleOperator(AwsBaseOperator):
    name: "str"
    event_bus_name: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class SparkKubernetesOperator(KubernetesPodOperator):
    image: "str | None"
    code_path: "str | None"
    namespace: "str"
    name: "str"
    application_file: "str | None"
    template_spec: "_empty"
    get_logs: "bool"
    do_xcom_push: "bool"
    success_run_history_limit: "int"
    startup_timeout_seconds: "_empty"
    log_events_on_failure: "bool"
    reattach_on_restart: "bool"
    delete_on_termination: "bool"
    kubernetes_conn_id: "str"



import importlib
import os

import click

from airfly.model import AirFly, TaskTree
from airfly.utils import qualname

from .utils import (
    convert_dag_params,
    convert_task_group,
    expand_sys_path,
    print_version,
    validate_includes,
)


@click.command()
@click.option(
    "--version",
    is_flag=True,
    callback=print_version,
    expose_value=False,
    is_eager=True,
    help="Show version and exit.",
)
@click.option("--name", "-n", help="Assign to DAG id.")
@click.option(
    "--modname",
    "-m",
    help=(
        "Name of the module to search tasks"
        " for building the task dependency tree"
        " and using it to generate the airflow DAG file."
    ),
)
@click.option(
    "--path",
    "-p",
    multiple=True,
    default=[os.getcwd()],
    help='Insert into "sys.path" to include certain modules, multi-value is allowed.',
)
@click.option(
    "--exclude-pattern",
    "-e",
    help=(
        "Exclude the tasks from the dependency tree"
        " if their __qualname__ get matched with this regex pattern."
    ),
)
@click.option(
    "--includes",
    "-i",
    callback=validate_includes,
    help=(
        "Paths of python files, the code within"
        " will be included in the output DAG file, multi-value is allowed."
    ),
    multiple=True,
)
@click.option(
    "--dag-params",
    "-d",
    callback=convert_dag_params,
    help=(
        "Parameters to construct DAG object,"
        " defined by a dictionary in a python file."
        " Pass this option with <python-file>:<variable> form,"
        " the <variable> should be the dictionary"
        " which will be passed to DAG as keyword arguments."
    ),
)
@click.option(
    "--task-class",
    "-t",
    default="airfly.model.AirFly",
    help=f"Target task class to search, default: '{qualname(AirFly)}'",
)
@click.option(
    "--task-group",
    "-g",
    callback=convert_task_group,
    default=True,
    help="Whether to enable TaskGroup, default: True",
)
def main(
    name, modname, path, exclude_pattern, includes, dag_params, task_class, task_group
):

    with expand_sys_path(*path):
        module = importlib.import_module(modname)

        taskmodule, taskname = task_class.rsplit(".", 1)
        taskmodule = importlib.import_module(taskmodule)
        taskclass = taskmodule.__dict__[taskname]

    name = name or f"{modname}_dag"

    if dag_params and dag_params[0]:
        if includes:
            includes.append(dag_params[0])
        else:
            includes = [dag_params[0]]

    tree = TaskTree.from_module(
        module, taskclass=taskclass, exclude_pattern=exclude_pattern
    )

    print(
        tree.to_dag(
            name, includes=includes, dag_params=dag_params, task_group=task_group
        ),
        end="",
    )



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudVisionCreateProductSetOperator(GoogleCloudBaseOperator):
    product_set: "dict | ProductSet"
    location: "str"
    project_id: "str"
    product_set_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionGetProductSetOperator(GoogleCloudBaseOperator):
    location: "str"
    product_set_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
    product_set: "dict | ProductSet"
    location: "str | None"
    product_set_id: "str | None"
    project_id: "str"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDeleteProductSetOperator(GoogleCloudBaseOperator):
    location: "str"
    product_set_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionCreateProductOperator(GoogleCloudBaseOperator):
    location: "str"
    product: "str"
    project_id: "str"
    product_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionGetProductOperator(GoogleCloudBaseOperator):
    location: "str"
    product_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
    product: "dict | Product"
    location: "str | None"
    product_id: "str | None"
    project_id: "str"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDeleteProductOperator(GoogleCloudBaseOperator):
    location: "str"
    product_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionImageAnnotateOperator(GoogleCloudBaseOperator):
    request: "dict | AnnotateImageRequest"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
    location: "str"
    reference_image: "dict | ReferenceImage"
    product_id: "str"
    reference_image_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDeleteReferenceImageOperator(GoogleCloudBaseOperator):
    location: "str"
    product_id: "str"
    reference_image_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionAddProductToProductSetOperator(GoogleCloudBaseOperator):
    product_set_id: "str"
    product_id: "str"
    location: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
    product_set_id: "str"
    product_id: "str"
    location: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    language_hints: "str | list[str] | None"
    web_detection_params: "dict | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    language_hints: "str | list[str] | None"
    web_detection_params: "dict | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudVisionDetectImageSafeSearchOperator(GoogleCloudBaseOperator):
    image: "dict | Image"
    max_results: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    additional_properties: "dict | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class LookerStartPdtBuildOperator(GoogleCloudBaseOperator):
    looker_conn_id: "str"
    model: "str"
    view: "str"
    query_params: "dict | None"
    asynchronous: "bool"
    cancel_on_kill: "bool"
    wait_time: "int"
    wait_timeout: "int | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.common.sql.operators.sql import (
    SQLCheckOperator,
    SQLExecuteQueryOperator,
    SQLIntervalCheckOperator,
    SQLValueCheckOperator,
)


class SnowflakeOperator(SQLExecuteQueryOperator):
    pass


class SnowflakeCheckOperator(SQLCheckOperator):
    sql: "str"
    snowflake_conn_id: "str"
    parameters: "Iterable | Mapping[str, Any] | None"
    autocommit: "bool"
    do_xcom_push: "bool"
    warehouse: "str | None"
    database: "str | None"
    role: "str | None"
    schema: "str | None"
    authenticator: "str | None"
    session_parameters: "dict | None"


class SnowflakeValueCheckOperator(SQLValueCheckOperator):
    sql: "str"
    pass_value: "Any"
    tolerance: "Any"
    snowflake_conn_id: "str"
    parameters: "Iterable | Mapping[str, Any] | None"
    autocommit: "bool"
    do_xcom_push: "bool"
    warehouse: "str | None"
    database: "str | None"
    role: "str | None"
    schema: "str | None"
    authenticator: "str | None"
    session_parameters: "dict | None"


class SnowflakeIntervalCheckOperator(SQLIntervalCheckOperator):
    table: "str"
    metrics_thresholds: "dict"
    date_filter_column: "str"
    days_back: "SupportsAbs[int]"
    snowflake_conn_id: "str"
    parameters: "Iterable | Mapping[str, Any] | None"
    autocommit: "bool"
    do_xcom_push: "bool"
    warehouse: "str | None"
    database: "str | None"
    role: "str | None"
    schema: "str | None"
    authenticator: "str | None"
    session_parameters: "dict | None"


class SnowflakeSqlApiOperator(SQLExecuteQueryOperator):
    snowflake_conn_id: "str"
    warehouse: "str | None"
    database: "str | None"
    role: "str | None"
    schema: "str | None"
    authenticator: "str | None"
    session_parameters: "dict[str, Any] | None"
    poll_interval: "int"
    statement_count: "int"
    token_life_time: "timedelta"
    token_renewal_delta: "timedelta"
    bindings: "dict[str, Any] | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToRedshiftOperator(BaseOperator):
    schema: "str"
    table: "str"
    s3_bucket: "str"
    s3_key: "str"
    redshift_conn_id: "str"
    aws_conn_id: "str | None"
    verify: "bool | str | None"
    column_list: "list[str] | None"
    copy_options: "list | None"
    autocommit: "bool"
    method: "str"
    upsert_keys: "list[str] | None"
    redshift_data_api_kwargs: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleSheetsToGCSOperator(BaseOperator):
    spreadsheet_id: "str"
    destination_bucket: "str"
    sheet_filter: "list[str] | None"
    destination_path: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.http.operators.http import HttpOperator


class DiscordWebhookOperator(HttpOperator):
    http_conn_id: "str | None"
    webhook_endpoint: "str | None"
    message: "str"
    username: "str | None"
    avatar_url: "str | None"
    tts: "bool"
    proxy: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DatabricksPartitionSensor(BaseSensorOperator):
    databricks_conn_id: "str"
    http_path: "str | None"
    sql_warehouse_name: "str | None"
    session_configuration: "_empty"
    http_headers: "list[tuple[str, str]] | None"
    catalog: "str"
    schema: "str"
    table_name: "str"
    partitions: "dict"
    partition_operator: "str"
    handler: "Callable[[Any], Any]"
    client_parameters: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DatadogSensor(BaseSensorOperator):
    datadog_conn_id: "str"
    from_seconds_ago: "int"
    up_to_seconds_from_now: "int"
    priority: "str | None"
    sources: "str | None"
    tags: "list[str] | None"
    response_check: "Callable[[dict[str, Any]], bool] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDataTransferServiceCreateJobOperator(GoogleCloudBaseOperator):
    body: "dict"
    aws_conn_id: "str | None"
    gcp_conn_id: "str"
    api_version: "str"
    project_id: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceUpdateJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    body: "dict"
    aws_conn_id: "str | None"
    gcp_conn_id: "str"
    api_version: "str"
    project_id: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceDeleteJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    project_id: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceRunJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    project_id: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceGetOperationOperator(GoogleCloudBaseOperator):
    project_id: "str"
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceListOperationsOperator(GoogleCloudBaseOperator):
    request_filter: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServicePauseOperationOperator(GoogleCloudBaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceResumeOperationOperator(GoogleCloudBaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceCancelOperationOperator(GoogleCloudBaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "str | Sequence[str] | None"


class CloudDataTransferServiceS3ToGCSOperator(GoogleCloudBaseOperator):
    s3_bucket: "str"
    gcs_bucket: "str"
    s3_path: "str | None"
    gcs_path: "str | None"
    project_id: "str"
    aws_conn_id: "str | None"
    gcp_conn_id: "str"
    description: "str | None"
    schedule: "dict | None"
    object_conditions: "dict | None"
    transfer_options: "dict | None"
    wait: "bool"
    timeout: "float | None"
    google_impersonation_chain: "str | Sequence[str] | None"
    delete_job_after_completion: "bool"
    aws_role_arn: "str | None"


class CloudDataTransferServiceGCSToGCSOperator(GoogleCloudBaseOperator):
    source_bucket: "str"
    destination_bucket: "str"
    source_path: "str | None"
    destination_path: "str | None"
    project_id: "str"
    gcp_conn_id: "str"
    description: "str | None"
    schedule: "dict | None"
    object_conditions: "dict | None"
    transfer_options: "dict | None"
    wait: "bool"
    timeout: "float | None"
    google_impersonation_chain: "str | Sequence[str] | None"
    delete_job_after_completion: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CohereEmbeddingOperator(BaseOperator):
    input_text: "list[str] | str"
    conn_id: "str"
    timeout: "int | None"
    max_retries: "int | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GenericTransfer(BaseOperator):
    sql: "str"
    destination_table: "str"
    source_conn_id: "str"
    destination_conn_id: "str"
    preoperator: "str | list[str] | None"
    insert_args: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToDynamoDBOperator(BaseOperator):
    s3_bucket: "str"
    s3_key: "str"
    dynamodb_table_name: "str"
    dynamodb_key_schema: "list[KeySchema]"
    dynamodb_attributes: "list[AttributeDefinition] | None"
    dynamodb_tmp_table_prefix: "str"
    delete_on_error: "bool"
    use_existing_table: "bool"
    input_format: "Literal['CSV', 'DYNAMODB_JSON', 'ION']"
    billing_mode: "Literal['PROVISIONED', 'PAY_PER_REQUEST']"
    import_table_kwargs: "dict[str, Any] | None"
    import_table_creation_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    check_interval: "int"
    max_attempts: "int"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class KylinCubeOperator(BaseOperator):
    kylin_conn_id: "str"
    project: "str | None"
    cube: "str | None"
    dsn: "str | None"
    command: "str | None"
    start_time: "str | None"
    end_time: "str | None"
    offset_start: "str | None"
    offset_end: "str | None"
    segment_name: "str | None"
    is_track_job: "bool"
    interval: "int"
    timeout: "int"
    eager_error_status: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AddOneOperator(BaseOperator):
    value: "_empty"


class SumItOperator(BaseOperator):
    values: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDLPCancelDLPJobOperator(GoogleCloudBaseOperator):
    dlp_job_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    deidentify_template: "dict | DeidentifyTemplate | None"
    template_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateDLPJobOperator(GoogleCloudBaseOperator):
    project_id: "str"
    inspect_job: "dict | InspectJobConfig | None"
    risk_job: "dict | RiskAnalysisJobConfig | None"
    job_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    wait_until_finished: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateInspectTemplateOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    inspect_template: "InspectTemplate | None"
    template_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateJobTriggerOperator(GoogleCloudBaseOperator):
    project_id: "str"
    job_trigger: "dict | JobTrigger | None"
    trigger_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPCreateStoredInfoTypeOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    config: "StoredInfoTypeConfig | None"
    stored_info_type_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeidentifyContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    deidentify_config: "dict | DeidentifyConfig | None"
    inspect_config: "dict | InspectConfig | None"
    item: "dict | ContentItem | None"
    inspect_template_name: "str | None"
    deidentify_template_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteDLPJobOperator(GoogleCloudBaseOperator):
    dlp_job_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteInspectTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteJobTriggerOperator(GoogleCloudBaseOperator):
    job_trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPDeleteStoredInfoTypeOperator(GoogleCloudBaseOperator):
    stored_info_type_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetDLPJobOperator(GoogleCloudBaseOperator):
    dlp_job_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetInspectTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetDLPJobTriggerOperator(GoogleCloudBaseOperator):
    job_trigger_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPGetStoredInfoTypeOperator(GoogleCloudBaseOperator):
    stored_info_type_id: "str"
    organization_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPInspectContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    inspect_config: "dict | InspectConfig | None"
    item: "dict | ContentItem | None"
    inspect_template_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListDeidentifyTemplatesOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListDLPJobsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    results_filter: "str | None"
    page_size: "int | None"
    job_type: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListInfoTypesOperator(GoogleCloudBaseOperator):
    project_id: "str"
    language_code: "str | None"
    results_filter: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListInspectTemplatesOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListJobTriggersOperator(GoogleCloudBaseOperator):
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    results_filter: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPListStoredInfoTypesOperator(GoogleCloudBaseOperator):
    organization_id: "str | None"
    project_id: "str"
    page_size: "int | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPRedactImageOperator(GoogleCloudBaseOperator):
    project_id: "str"
    inspect_config: "dict | InspectConfig | None"
    image_redaction_configs: (
        "None | (list[dict] | list[RedactImageRequest.ImageRedactionConfig])"
    )
    include_findings: "bool | None"
    byte_item: "dict | ByteContentItem | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPReidentifyContentOperator(GoogleCloudBaseOperator):
    project_id: "str"
    reidentify_config: "dict | DeidentifyConfig | None"
    inspect_config: "dict | InspectConfig | None"
    item: "dict | ContentItem | None"
    inspect_template_name: "str | None"
    reidentify_template_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateDeidentifyTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    deidentify_template: "dict | DeidentifyTemplate | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateInspectTemplateOperator(GoogleCloudBaseOperator):
    template_id: "str"
    organization_id: "str | None"
    project_id: "str"
    inspect_template: "dict | InspectTemplate | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateJobTriggerOperator(GoogleCloudBaseOperator):
    job_trigger_id: "_empty"
    project_id: "str"
    job_trigger: "dict | JobTrigger | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDLPUpdateStoredInfoTypeOperator(GoogleCloudBaseOperator):
    stored_info_type_id: "_empty"
    organization_id: "str | None"
    project_id: "str"
    config: "dict | StoredInfoTypeConfig | None"
    update_mask: "dict | FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SFTPOperator(BaseOperator):
    ssh_hook: "SSHHook | None"
    sftp_hook: "SFTPHook | None"
    ssh_conn_id: "str | None"
    remote_host: "str | None"
    local_filepath: "str | list[str]"
    remote_filepath: "str | list[str]"
    operation: "str"
    confirm: "bool"
    create_intermediate_dirs: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AwaitMessageSensor(BaseOperator):
    topics: "Sequence[str]"
    apply_function: "str"
    kafka_config_id: "str"
    apply_function_args: "Sequence[Any] | None"
    apply_function_kwargs: "dict[Any, Any] | None"
    poll_timeout: "float"
    poll_interval: "float"
    xcom_push_key: "_empty"


class AwaitMessageTriggerFunctionSensor(BaseOperator):
    topics: "Sequence[str]"
    apply_function: "str"
    event_triggered_function: "Callable"
    kafka_config_id: "str"
    apply_function_args: "Sequence[Any] | None"
    apply_function_kwargs: "dict[Any, Any] | None"
    poll_timeout: "float"
    poll_interval: "float"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
    bucket: "str"
    namespace: "str | None"
    datastore_conn_id: "str"
    cloud_storage_conn_id: "str"
    entity_filter: "dict | None"
    labels: "dict | None"
    polling_interval_in_seconds: "int"
    overwrite_existing: "bool"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
    bucket: "str"
    file: "str"
    namespace: "str | None"
    entity_filter: "dict | None"
    labels: "dict | None"
    datastore_conn_id: "str"
    polling_interval_in_seconds: "float"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
    partial_keys: "list"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
    transaction_options: "dict[str, Any]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
    body: "dict[str, Any]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
    transaction: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
    body: "dict[str, Any]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
    name: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
    name: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class TableauJobStatusSensor(BaseSensorOperator):
    job_id: "str"
    site_id: "str | None"
    tableau_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class TaskQueueEmptySensor(BaseSensorOperator):
    location: "str"
    project_id: "str"
    queue_name: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class OpenSearchServerlessCollectionActiveSensor(AwsBaseSensor):
    collection_id: "str | None"
    collection_name: "str | None"
    poke_interval: "int"
    max_retries: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToMySqlOperator(BaseOperator):
    s3_source_key: "str"
    mysql_table: "str"
    mysql_duplicate_key_handling: "str"
    mysql_extra_options: "str | None"
    aws_conn_id: "str | None"
    mysql_conn_id: "str"
    mysql_local_infile: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class GlacierCreateJobOperator(AwsBaseOperator):
    vault_name: "str"


class GlacierUploadArchiveOperator(AwsBaseOperator):
    vault_name: "str"
    body: "object"
    checksum: "str | None"
    archive_description: "str | None"
    account_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleCalendarToGCSOperator(BaseOperator):
    destination_bucket: "str"
    api_version: "str"
    calendar_id: "str"
    i_cal_uid: "str | None"
    max_attendees: "int | None"
    max_results: "int | None"
    order_by: "str | None"
    private_extended_property: "str | None"
    text_search_query: "str | None"
    shared_extended_property: "str | None"
    show_deleted: "bool | None"
    show_hidden_invitation: "bool | None"
    single_events: "bool | None"
    sync_token: "str | None"
    time_max: "datetime | None"
    time_min: "datetime | None"
    time_zone: "str | None"
    updated_min: "datetime | None"
    destination_path: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
